<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Product;
use App\Models\ProductCard;
use App\Models\ProductImage;
use App\Models\ProductTags;
use App\Models\Tag;
use Illuminate\Http\Request;

class CardsController extends Controller
{

    public function index()
    {
        $rows = Product::where('online_card', 'true')->get();
        return view('admin.cards.index', compact('rows'));
    }

    public function create()
    {
        $categories = Category::all();
        $tags = Tag::all();
        return view('admin.cards.create', compact('categories', 'tags'));
    }

    public function store(Request $request)
    {

        $this->validate($request, [
            'title' => 'required|max:191',
            'client_price' => 'required|numeric',
            'merchant_price' => 'required|numeric',
            'description' => 'required',
            'sale' => 'required|in:true,false',
            'product_images' => 'required|array',
            'category_id' => 'required|exists:categories,id',
            'tags' => 'required|array',
            'all_cards' => 'required'
        ]);

        $string_first = $request->all_cards;
        $string = preg_replace(["/<br\W*?\/>/", "/<p>/", "/<\/p>/"], " ", $string_first);
        $dataList = substr($string, 1, -1);
        $cards = explode(' ', $dataList);

        $product = Product::create($request->all());
        $product->online_card = 'true';
        $product->count = count($cards);
        $product->update();

        foreach ($request->product_images as $product_image) {
            $image = new ProductImage();
            $image->setImageAttribute($product_image);
            $image->product_id = $product->id;
            $image->save();
        }

        foreach ($request->tags as $tag) {
            $product_tag = new ProductTags();
            $product_tag->product_id = $product->id;
            $product_tag->tag_id = $tag;
            $product_tag->save();
        }

        foreach ($cards as $card) {
            $new_card = new ProductCard();
            $new_card->product_id = $product->id;
            $new_card->available = 'true';
            $new_card->card_code = $card;
            $new_card->save();
        }

        success_toast();
        return redirect()->route('cards.index');
    }

    public function edit($id)
    {
        $row = Product::findOrFail($id);
        $product_cards = $row->product_cards;
        $categories = Category::all();
        $tags = Tag::all();
        $count = ProductCard::where(['product_id' => $id, 'available' => true])->count();
        $row->count = $count;
        $row->update();
        return view('admin.cards.edit', compact('row', 'categories', 'tags', 'product_cards'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'title' => 'required|max:191',
            'client_price' => 'required|numeric',
            'merchant_price' => 'required|numeric',
            'description' => 'required',
            'sale' => 'required|in:true,false',
            'category_id' => 'required|exists:categories,id',
        ]);

        if($request->all_cards){
            $string_first = $request->all_cards;
            $string = preg_replace(["/<br\W*?\/>/", "/<p>/", "/<\/p>/"], " ", $string_first);
            $dataList = substr($string, 1, -1);
            $cards = explode(' ', $dataList);

            foreach ($cards as $card) {
                $new_card = new ProductCard();
                $new_card->product_id = $id;
                $new_card->available = 'true';
                $new_card->card_code = $card;
                $new_card->save();
            }

        }

        $count = ProductCard::where(['product_id' => $id, 'available' => true])->count();
        $request['count'] = $count;
        Product::whereId($id)->update($request->except('_method', '_token', 'tags'));

        if ($request->product_images) {
            foreach ($request->product_images as $product_image) {
                $image = new ProductImage();
                $image->setImageAttribute($product_image);
                $image->product_id = $id;
                $image->save();
            }
        }

        if ($request->tags) {
            foreach ($request->tags as $tag) {
                $product_tag = new ProductTags();
                $product_tag->product_id = $id;
                $product_tag->tag_id = $tag;
                $product_tag->save();
            }
        }

        success_toast();
        return redirect()->route('cards.index');
    }


    public function destroy_image($id)
    {
        ProductImage::destroy($id);
        success_toast();
        return back();
    }

    public function destroy_card($id)
    {
        ProductCard::destroy($id);
        success_toast();
        return back();
    }


    public function destroy($id)
    {
        Product::destroy($id);
        success_toast();
        return back();
    }
}
