<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Mail\ProductCardsAdmin;
use App\Mail\ProductCardsMail;
use App\Models\Notification;
use App\Models\Order;
use App\Models\Product;
use App\Models\ProductCard;
use Illuminate\Http\Request;

class OrdersController extends Controller
{
    public function index()
    {
        $rows = Order::latest()->get();
        return view('admin.orders.index', compact('rows'));
    }

    public function create()
    {
        //    return view('admin.orders.create');
    }

    public function store(Request $request)
    {
        //
    }

    public function show($id)
    {
        $row = Order::find($id);
        $carts = $row->order_carts()->get();
        return view('admin.orders.show', compact('row', 'carts'));
    }

    public function edit($id)
    {
        $row = Order::findOrFail($id);
        return view('admin.orders.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'status' => 'required|in:waiting,new,finished,cancel'
        ]);
        $order = Order::find($id);
        if ($order->status == 'cancel') {
            alert('خطأ', 'تم الغاء الاوردر من قبل', 'error');
            return redirect()->back();
        }
        Order::whereId($id)->update($request->except('_method', '_token'));


        if ($order->status != 'cancel' && $request->status == 'cancel') {

            $carts = $order->order_carts()->get();
            $cards = $order->order_cards()->get();

            foreach ($carts as $cart) {
                $product = Product::find($cart->product_id);
                $product->count += $cart->count;
                $product->update();
            }

            foreach ($cards as $card) {
                $product_card = ProductCard::find($card->id);
                $product_card->available = 'true';
                $product_card->update();
            }

        }

        $notification = new Notification();
        $notification->user_id = $order->user_id;
        $notification->title = "طلب رقم $id";
        if ($order->card == 'true' && $request->status == 'finished') {
            $product_card_ids = $order->order_cards()->pluck('product_cards.id');

            \Mail::to($order->user->email)->send(new ProductCardsAdmin($product_card_ids));


            $order->card = 'sent';
            $order->update();
            $notification->description = "تم تغير حالة الطلب الى منتهى وتم ارسال الكروت الخاصه بالطلب على البريد الالكترونى";
        } else {
            $notification->description = "تم تغير حالة الطلب الى " . status_order()
                [$request->status];
        }
        $notification->save();

        success_toast();
        return redirect()->route('orders.index');
    }

    public function destroy($id)
    {
        Order::destroy($id);
        success_toast();
        return back();
    }
}
