<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Product;
use App\Models\ProductImage;
use App\Models\ProductTags;
use App\Models\Tag;
use Illuminate\Http\Request;

class ProductsController extends Controller
{
    public function index()
    {
        $rows = Product::all();
        return view('admin.products.index', compact('rows'));
    }

    public function create()
    {
        $categories = Category::all();
        $tags = Tag::all();
        return view('admin.products.create', compact('categories', 'tags'));
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required|max:191',
            'client_price' => 'required|numeric',
            'merchant_price' => 'required|numeric',
            'count' => 'required|numeric',
            'description' => 'required',
            'sale' => 'required|in:true,false',
            'product_images' => 'required|array',
            'category_id' => 'required|exists:categories,id',
            'tags' => 'required|array',
        ]);
        $product = Product::create($request->all());
        $product->online_card = 'false';
        $product->update();

        foreach ($request->product_images as $product_image) {
            $image = new ProductImage();
            $image->setImageAttribute($product_image);
            $image->product_id = $product->id;
            $image->save();
        }

        foreach ($request->tags as $tag) {
            $product_tag = new ProductTags();
            $product_tag->product_id = $product->id;
            $product_tag->tag_id = $tag;
            $product_tag->save();
        }

        success_toast();
        return redirect()->route('products.index');
    }

    public function edit($id)
    {
        $row = Product::findOrFail($id);
        $categories = Category::all();
        $tags = Tag::all();
        return view('admin.products.edit', compact('row', 'categories', 'tags'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'title' => 'required|max:191',
            'client_price' => 'required|numeric',
            'merchant_price' => 'required|numeric',
            'count' => 'required|numeric',
            'description' => 'required',
            'sale' => 'required|in:true,false',
            'category_id' => 'required|exists:categories,id',
        ]);
        $product = Product::whereId($id)->update($request->except('_method', '_token', 'tags'));

        if ($request->product_images) {
            foreach ($request->product_images as $product_image) {
                $image = new ProductImage();
                $image->setImageAttribute($product_image);
                $image->product_id = $product->id;
                $image->save();
            }
        }

        if ($request->tags) {
            foreach ($request->tags as $tag) {
                $product_tag = new ProductTags();
                $product_tag->product_id = $id;
                $product_tag->tag_id = $tag;
                $product_tag->save();
            }
        }

        success_toast();
        return redirect()->route('products.index');
    }


    public function destroy_image($id)
    {
        ProductImage::destroy($id);
        success_toast();
        return back();
    }

    public function destroy_tag($id)
    {
        ProductTags::destroy($id);
        success_toast();
        return back();
    }

    public function destroy($id)
    {
        Product::destroy($id);
        success_toast();
        return back();
    }
}
