<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;

class UsersController extends Controller
{
    public function index()
    {
        $rows = User::where('type', 'client')->get();
        return view('admin.users.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.users.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required|max:191',
            'email' => 'required|email|unique:users,email|max:191',
            'mobile' => 'required|unique:users,mobile|max:191',
            'status' => 'required|in:active,not_active',
            'wallet' => 'nullable|numeric',
            'points' => 'nullable|numeric',
            'image' => 'nullable|image',
            'password' => 'required|min:6|max:191',

        ]);
        $user = new User();
        $user->name = $request['name'];
        $user->mobile = $request['mobile'];
        $user->email = $request['email'];
        $user->wallet = $request['wallet'];
        $user->points = $request['points'];
        $user->type = 'client';
        $user->status = $request['status'];
        if($request->hasFile('image'))$user->setImageAttribute();
        $user->password = bcrypt($request['password']);
        $user->save();


        toast('تم الاضافة بنجاح','success');
        return redirect()->route('users.index');

    }

    public function edit($id)
    {
        $row = User::findOrFail($id);


        return view('admin.users.edit', compact('row'));
    }

    public function update(Request $request, $id)
    {


        $this->validate($request, [
            'name' => 'required|max:191',
            'email' => 'required|email|max:191|unique:users,email,'.$id,
            'mobile' => 'required|max:191|unique:users,mobile,'.$id,
            'status' => 'required|in:active,not_active',
            'wallet' => 'nullable|numeric',
            'points' => 'nullable|numeric',
            'image' => 'nullable|image',
            'password' => 'nullable|min:6|max:191',

        ]);
        $user = User::findOrFail($id);
        $user->name = $request['name'];
        $user->mobile = $request['mobile'];
        $user->email = $request['email'];
        $user->wallet = $request['wallet'];
        $user->points = $request['points'];
        $user->status = $request['status'];
        if($request->hasFile('image'))$user->setImageAttribute();
        $user->password = bcrypt($request['password']);
        $user->update();

toast('تم التعديل بنجاح','success');
        return redirect()->route('users.index');

    }

    public function destroy($id)
    {
        User::destroy($id);
        success_toast();
        return back();

    }
}
