<?php

namespace App\Http\Controllers\Site;

use App\Http\Controllers\Controller;
use App\Models\Cart;
use App\Models\PointCart;
use App\Models\PointProduct;
use App\Models\Setting;
use Illuminate\Http\Request;

class PointCartsController extends Controller
{


    public function add_point_product_to_cart(Request $request)
    {
        $this->validate($request, [
            'point_product_id' => 'required|exists:point_products,id',
            'count' => 'required',
        ]);

        $product = PointProduct::find($request->point_product_id);
        if (\Auth::user()->type == 'client') {
            $price = $product->client_point;
        } else {
            $price = $product->merchant_point;
        }

        $cart_product = PointCart::where(['user_id' => \Auth::user()->id, 'point_product_id' => $request->point_product_id, 'status' => 'cart'])->first();

        if (!$cart_product) {
            $cart = new PointCart();
            $cart->user_id = \Auth::user()->id;
            $cart->point_product_id = $request->point_product_id;
            $cart->count = $request->count;
            $cart->total_points = $price * $request->count;
            $cart->status = 'cart';
            $cart->save();
            alert('الاضافه الى السلة', 'تم اضافه المنتج الى السلة بنجاح', 'success');
            return redirect()->back();
        } else {
            $cart = PointCart::find($cart_product->id);
            $count = $cart->count + $request->count;
            $cart->count = $count;
            $cart->total_points = $price * $count;
            $cart->update();

        }
        alert('تعديل السلة', 'تم اضافه المنتج وتعديل كميته فى السلة بنجاح', 'success');
        return redirect()->back();
    }

    public function my_cart_points()
    {
        $rows = \Auth::user()->point_carts()->where(['status' => 'cart'])->get();

        $total_points_products = PointCart::where(['status' => 'cart', 'user_id' => \Auth::user()->id])->sum('total_points');

        return view('site.carts.point_cart', compact('rows', 'total_points_products'));
    }


    public function update_point_cart_ajax(Request $request)
    {
        $cart = PointCart::find($request->id);
        $product = PointProduct::find($cart->point_product_id);
        $count = $request->count;

        if ($count == 0) {
            return response()->json(['value' => false, 'msg' => 'لا يمكن اختيار الكميه 0', 'count' => $cart->count]);
        }

        if ($request->type == 'plus') {

            if ($count > $product->count) {
                return response()->json(['value' => false, 'msg' => 'غير متوفر هذه الكميه فى المنتج', 'count' => $cart->count]);
            }

        }

        if ($count > $product->count) {
            $type = 'false';
        } else {
            $type = 'true';
        }

        if (\Auth::user()->type == 'client') {
            $price = $product->client_point;
        } else {
            $price = $product->merchant_point;
        }
        $cart->count = $count;
        $cart->total_points = $price * $count;
        $cart->update();
        $total_points = $cart->total_points . ' نقطة';
        $total_points_all = PointCart::where(['user_id' => \Auth::user()->id, 'status' => 'cart'])->sum('total_points');

        return response()->json(['value' => true, 'total_points' => $total_points, 'total_points_all' => $total_points_all . ' نقطة', 'type' => $type]);
    }


    public function delete_point_cart($id)
    {
        $cart = PointCart::find($id);
        $cart->delete();
        toast('تم مسح المنتج من السلة', 'success');
        return redirect()->back();
    }


}
