<?php

namespace App\Http\Controllers\Site;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Favourite;
use App\Models\Product;
use App\Models\User;
use Illuminate\Http\Request;

class ProductsController extends Controller
{

    public function my_favourite()
    {
        $rows = \Auth::user()->favourites()->latest()->paginate(12);
        return view('site.products.favourite', compact('rows'));
    }

    public function favourite(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'product_id' => 'required'
        ]);

        if (!\Auth::check()) return response()->json(['value' => 'false', 'msg' => 'يجب التسجبل اولا']);

        if ($validator->passes()) {

            $check = Favourite::where(['user_id' => \Auth::user()->id, 'product_id' => $request['product_id']])->first();
            if ($check) {
                $check->delete();
                $removed_class = 'active';
                $added_class = '';
                $message = 'تم حذف المنتج من المفضلة';
                $count = Favourite::where('user_id', \Auth::user()->id)->count();

            } else {

                Favourite::create(['user_id' => \Auth::user()->id, 'product_id' => $request['product_id']]);
                $removed_class = '';
                $added_class = 'active';
                $message = 'تم اضافة المنتج الى المفضلة';
                $count = Favourite::where('user_id', \Auth::user()->id)->count();
            }

            return response()->json(['value' => 'true', 'data' => $message, 'removed_class' => $removed_class, 'count' => $count, 'added_class' => $added_class]);


        } else {
            return response()->json(['value' => 'false', 'msg' => $validator->errors()->first()]);
        }
    }

    public function product_details($id)
    {
        $row = Product::find($id);
        $relates = Product::where('category_id', $row->category_id)->take(3)->get();
        return view('site.products.product_details', compact('row', 'relates'));
    }

    public function categories()
    {
        $categories = Category::whereHas('products')->get();
//        dd($categories);
        return view('site.products.categories', compact('categories'));
    }

    public function search(Request $request)
    {
        $this->validate($request, [
            'title' => 'required'
        ]);

        $rows = Product::where('title', 'LIKE', "%{$request->title}%")->paginate(12);
        return view('site.search', compact('rows'));
    }

}
