<?php

namespace App\Http\Controllers\Site;

use App\Http\Controllers\Controller;
use App\Mail\VerifyEmail;
use App\Models\Bank;
use App\Models\User;
use App\Models\WalletCharge;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Rules\MatchOldPassword;

class UsersController extends Controller
{
    public function sign_up_form()
    {
        return view('site.users.sign_up');
    }

    public function login_form()
    {
        return view('site.users.login');
    }

    public function authentication(Request $request)
    {
        $this->validate($request, [
            'email' => 'required',
            'password' => 'required',
            'type' => 'required|in:client,merchant'
        ]);


        if (\Auth::attempt(['email' => $request['email'], 'password' => $request['password'], 'status' => 'active', 'type' => $request->type])) {
            $user = Auth::user();
            if ($user->verification_status == "false") {

                $code = rand(11111, 99999) . $user->id;
                $user->verification_code = $code;
                $user->update();
                //send code to email
                $message = "عميلنا العزيز رمز التفعيل الخاص بكم هو $user->code";
//                shamel_sms($mobile, $message);

                //ToDO:  ارسال رسالة على البريد الالكترونى
                \Mail::to($user->email)->send(new VerifyEmail($user->verification_code));

//                Auth::logout();

                toast('برجاء تفعيل الحساب', 'success', 'left');
                return redirect()->route('activate_account');
            }
            toast('اهلا بك ' . $user->name . 'فى الموقع', 'success', 'left');
            return redirect()->route('home');
        } elseif (\Auth::attempt(['email' => $request['email'], 'password' => $request['password'], 'status' => 'not_active', 'type' => $request->type])) {
            toast('الحساب موقوف برجاء التواصل مع الاداره', 'error', 'left');
            return redirect()->back();
        } else {
            toast('البريد الالكترونى او كلة المرور غير صحيحة', 'error', 'left');
            return redirect()->back();
        }
    }


    public function sign_up_post(Request $request)
    {
        $this->validate($request, [
            'name' => 'required|min:6|max:191',
            'email' => 'required|email|unique:users,email',
            'mobile' => 'required|numeric|unique:users,email',
            'password' => 'required|confirmed',
            'type' => 'required|in:client,merchant',
            'commercial_image' => 'required_if:type,merchant',
            'image' => 'required'
        ]);
        $user = new User();
        $user->name = $request->name;
        $user->email = $request->email;
        $user->mobile = $request->mobile;
        $user->password = bcrypt($request->password);
        $user->type = $request->type;
        if ($request->hasFile('image')) $user->setImageAttribute();
        if ($request->hasFile('commercial_image')) $user->setCommercialImageAttribute();
        $user->market_link = $request->market_link;
        $user->status = 'active';
        $user->verification_status = 'false';
        $user->verification_code = rand('1111', '9999');
        $user->save();

        //TOdo: ارسال رسالة بالبريد الالكتروني

        \Mail::to($user->email)->send(new VerifyEmail($user->verification_code));
        Auth::login($user);
        toast('اهلا بك ' . $user->name . '  فى الموقع  ', 'success', 'left');
        return redirect()->route('activate_account');
    }

    public function activate_account()
    {
        return view('site.users.activate_account');
    }

    public function activate_account_post(Request $request)
    {
        $this->validate($request, [
            'code' => 'required'
        ]);
        $user = Auth::user();
        if ($user->verification_code != $request->code) {
            toast('الرمز غير صحيح', 'error');
            return redirect()->back();
        }
        $user->verification_code = null;
        $user->verification_status = 'true';
        $user->update();

        toast('تم تفعيل الحساب بنجاح', 'success');
        return redirect()->route('home');
    }

    public function forget_password_form()
    {
        return view('site.users.forget_password');
    }

    public function forget_password_email(Request $request)
    {
        $this->validate($request, [
            'email' => 'required|email'
        ]);

        $user = User::where('email', $request->email)->first();

        if (!$user) {
            toast('البريد الالكترونى غير صحيح', 'error');
            return redirect()->back();
        }
        $code = rand('1111', '9999');
        $user->verification_code = $code;
        $user->update();
        //TOdo: ارسال رسالة بالبريد الالكتروني
        \Mail::to($user->email)->send(new VerifyEmail($user->verification_code));


        \Session::put('email', $user->email);

        toast('تم ارسال رمز التحقق', 'success');
        return redirect()->route('forget_password_code_form');
    }

    public function forget_password_code_form()
    {
        return view('site.users.forget_password_code');
    }


    public function forget_password_code(Request $request)
    {

        $this->validate($request, [
            'code' => 'required'
        ]);

        $user = User::where(['email' => \Session::get('email'), 'verification_code' => $request->code])->first();

        if (!$user) {
            toast('الرمز غير صحيح', 'error');
            return redirect()->back();
        }
        \Session::put('code', $request->code);
        toast('تم التاكد من الرمز برجاء تغير كلمة المرور', 'success');
        return redirect()->route('forget_change_password_form');
    }

    public function forget_change_password_form()
    {
        if (\Session::get('code') && \Session::get('email')) {
            return view('site.users.forget_change_password');
        }
        return redirect()->route('home');
    }


    public function forget_change_password(Request $request)
    {
        $this->validate($request, [
            'password' => 'required|confirmed'
        ]);

        $user = User::where(['email' => \Session::get('email'), 'verification_code' => \Session::get('code')])->first();

        $user->password = bcrypt($request->password);
        $user->update();

        \Session::forget('email');
        \Session::forget('code');

        toast('تم تغير كلمة المرور بنجاح', 'success');
        return redirect()->route('home');
    }


    public function wallet_charge()
    {
        $banks = Bank::all();
        return view('site.users.wallet', compact('banks'));
    }

    public function wallet_charge_post(Request $request)
    {
        $this->validate($request, [
            'bank_id' => 'required',
            'amount' => 'required',
            'transfer_number' => 'required',
            'transfer_date' => 'required',
            'transfer_name' => 'required',
            'transfer_image' => 'required|image',
            'pledge' => 'required'
        ]);
        $wallet = new WalletCharge();
        $wallet->user_id = Auth::user()->id;
        $wallet->bank_id = $request->bank_id;
        $wallet->amount = $request->amount;
        $wallet->transfer_number = $request->transfer_number;
        $wallet->transfer_date = $request->transfer_date;
        $wallet->transfer_name = $request->transfer_name;
        if ($request->hasFile('transfer_image')) {
            $wallet->setTransferImageAttribute();
        }
        $wallet->status = 'new';
        $wallet->save();
        toast('تم ارسال التحويل للاداره بنجاح', 'success');
        return redirect()->route('home');

    }

    public function update_profile()
    {
        return view('site.users.update_profile');
    }

    public function update_profile_post(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'mobile' => 'required|unique:users,mobile,'.$id,
            'email' => 'required|email|unique:users,email,'.$id,
            'image' => 'nullable|image',
        ]);
        $user = User::find($id);
        $user->name = $request->name;
        $user->email = $request->email;
        $user->mobile = $request->mobile;
        $user->market_link = $request['market_link'];
        if ($request->hasFile('image')) {
            $user->setImageAttribute();
        }
        $user->update();
        toast('تم تحديث الاعدادات بنجاح', 'success');
        return redirect()->back();

    }


    public function update_password()
    {
        return view('site.users.change_password');
    }

    public function update_password_post(Request $request, $id)
    {

        $this->validate($request, [
            'password_now' => ['required', new MatchOldPassword],
            'password' => 'required|confirmed|min:6',
        ]);

        $user = User::find($id);
        $user->password = bcrypt($request->password);
        $user->update();
        toast('تم تغير كلمة المرور بنجاح', 'success');
        return redirect()->back();

    }


    public function logout()
    {
        Auth::logout();
        return redirect()->route('home');
    }
}
